==> bouml_4.12.1.orig.tar.gz: bouml_4.12.1/genplugouts/xmi2/UmlActivityControlNodeClasses.h <==
#ifndef _UMLACTIVITYCONTROLNODECLASSES_H
#define _UMLACTIVITYCONTROLNODECLASSES_H


#include "UmlBaseActivityControlNodeClasses.h"
#include <qcstring.h>

class UmlInitialActivityNode : public UmlBaseInitialActivityNode {
  public:
    //  the constructor, do not call it yourself !!!!!!!!!!
     UmlInitialActivityNode(void * id, const QCString & s) : UmlBaseInitialActivityNode(id, s) {
    }

    virtual const char * sKind() const;

};

class UmlFlowFinalActivityNode : public UmlBaseFlowFinalActivityNode {
  public:
    //  the constructor, do not call it yourself !!!!!!!!!!
     UmlFlowFinalActivityNode(void * id, const QCString & s) : UmlBaseFlowFinalActivityNode(id, s) {
    }

    virtual const char * sKind() const;

};

class UmlActivityFinalActivityNode : public UmlBaseActivityFinalActivityNode {
  public:
    //  the constructor, do not call it yourself !!!!!!!!!!
     UmlActivityFinalActivityNode(void * id, const QCString & s) : UmlBaseActivityFinalActivityNode(id, s) {
    }

    virtual const char * sKind() const;

};

class UmlDecisionActivityNode : public UmlBaseDecisionActivityNode {
  public:
    //  the constructor, do not call it yourself !!!!!!!!!!
     UmlDecisionActivityNode(void * id, const QCString & s) : UmlBaseDecisionActivityNode(id, s) {
    }

    virtual const char * sKind() const;

};

class UmlMergeActivityNode : public UmlBaseMergeActivityNode {
  public:
    //  the constructor, do not call it yourself !!!!!!!!!!
     UmlMergeActivityNode(void * id, const QCString & s) : UmlBaseMergeActivityNode(id, s) {
    }

    virtual const char * sKind() const;

};

class UmlForkActivityNode : public UmlBaseForkActivityNode {
  public:
    //  the constructor, do not call it yourself !!!!!!!!!!
     UmlForkActivityNode(void * id, const QCString & s) : UmlBaseForkActivityNode(id, s) {
    }

    virtual const char * sKind() const;

};

class UmlJoinActivityNode : public UmlBaseJoinActivityNode {
  public:
    //  the constructor, do not call it yourself !!!!!!!!!!
     UmlJoinActivityNode(void * id, const QCString & s) : UmlBaseJoinActivityNode(id, s) {
    }

    virtual const char * sKind() const;

};

#endif

==> bouml_4.21.orig.tar.gz: bouml_4.21/genplugouts/xmi2/UmlActivityControlNodeClasses.h <==
#ifndef _UMLACTIVITYCONTROLNODECLASSES_H
#define _UMLACTIVITYCONTROLNODECLASSES_H


#include "UmlBaseActivityControlNodeClasses.h"
#include <qcstring.h>

class UmlInitialActivityNode : public UmlBaseInitialActivityNode {
  public:
    //  the constructor, do not call it yourself !!!!!!!!!!
     UmlInitialActivityNode(void * id, const QCString & s) : UmlBaseInitialActivityNode(id, s) {
    }

    virtual const char * sKind() const;

    virtual void solve_output_flows();

};

class UmlFlowFinalActivityNode : public UmlBaseFlowFinalActivityNode {
  public:
    //  the constructor, do not call it yourself !!!!!!!!!!
     UmlFlowFinalActivityNode(void * id, const QCString & s) : UmlBaseFlowFinalActivityNode(id, s) {
    }

    virtual const char * sKind() const;

    virtual void solve_output_flows();

};

class UmlActivityFinalActivityNode : public UmlBaseActivityFinalActivityNode {
  public:
    //  the constructor, do not call it yourself !!!!!!!!!!
     UmlActivityFinalActivityNode(void * id, const QCString & s) : UmlBaseActivityFinalActivityNode(id, s) {
    }

    virtual const char * sKind() const;

    virtual void solve_output_flows();

};

class UmlDecisionActivityNode : public UmlBaseDecisionActivityNode {
  public:
    //  the constructor, do not call it yourself !!!!!!!!!!
     UmlDecisionActivityNode(void * id, const QCString & s) : UmlBaseDecisionActivityNode(id, s) {
    }

    virtual const char * sKind() const;

    virtual void solve_output_flows();

};

class UmlMergeActivityNode : public UmlBaseMergeActivityNode {
  public:
    //  the constructor, do not call it yourself !!!!!!!!!!
     UmlMergeActivityNode(void * id, const QCString & s) : UmlBaseMergeActivityNode(id, s) {
    }

    virtual const char * sKind() const;

    virtual void solve_output_flows();

};

class UmlForkActivityNode : public UmlBaseForkActivityNode {
  public:
    //  the constructor, do not call it yourself !!!!!!!!!!
     UmlForkActivityNode(void * id, const QCString & s) : UmlBaseForkActivityNode(id, s) {
    }

    virtual const char * sKind() const;

    virtual void solve_output_flows();

};

class UmlJoinActivityNode : public UmlBaseJoinActivityNode {
  public:
    //  the constructor, do not call it yourself !!!!!!!!!!
     UmlJoinActivityNode(void * id, const QCString & s) : UmlBaseJoinActivityNode(id, s) {
    }

    virtual const char * sKind() const;

    virtual void solve_output_flows();

};

#endif
